#!/usr/bin/env python2

# Convert JSON from Qosmos protocol_records.js
# into YANG for vyatta-dpi-application-names-v1.yang

# Copyright (c) 2018, AT&T Intellectual Property. All rights reserved.

# TODO
#
# * Parse existing yang:
#       - build "existinglist" from existing yang
#       - ensure all existing names are in new yang
#       - re-emit names in same order; new names at end
#       - reproduce headers from existing yang into output yang.
#
# * Parse "dpi --list-app-names":
#       - ensure yang is emitted for each name, no more and no less.
#
# * Convert to python3
#

import json
import string
from HTMLParser import HTMLParser
import getopt, sys

blacklist = [ "8021ad", "8021q", "arp", "capwap", "cdp", "eth", "etherip",
              "garp", "gre", "gtp", "icmp", "ip", "ip6", "ipx", "l2tp",
              "llc", "mobile_ip", "mpls", "netbios", "pp", "ppp", "pppoe",
              "pwe", "sctp", "snap", "stp", "tcp", "udp", "vxlan" ]

existinglist = [
"01net",
"050plus",
"0zz0",
"10050net",
"10086cn",
"104com",
"1111tw",
"114la",
"115com",
"118114cn",
"11st",
"123people",
"1337x",
"139mail",
"15min",
"163com",
"17173com",
"17u",
"20min",
"24h",
"24ora",
"24sata",
"24ur",
"2ch",
"2shared",
"3366_com",
"360buy",
"360cn",
"3gpp_li",
"3pc",
"4399com",
"4chan",
"4shared",
"4tube",
"51_com",
"51_com_bbs",
"51_com_music",
"51_com_posting",
"51job",
"51la",
"56com",
"58com",
"591tw",
"5pmweb",
"6alabat",
"6play",
"7k7k",
"802_11",
"8tracks",
"91com",
"999_md",
"99acres",
"9game",
"a_dakar",
"aajtak",
"aastocks",
"abc",
"abc_au",
"abc_news",
"abcnews",
"abidjan",
"abola",
"about",
"abs_cbn",
"abs_cbnnews",
"abv",
"ac_reunion",
"acbar",
"accuweather",
"aceproject",
"acer",
"acrobat",
"acse",
"activenet",
"activesync",
"actuniger",
"adaderana",
"adc",
"adcash",
"adcolony",
"addictinggames",
"addthis",
"adf",
"adform",
"adjara",
"adjaranet",
"adjust",
"adk2",
"adnetworkperformance",
"adnstream",
"adobe",
"adobe_connect",
"adobe_meeting_rc",
"adobe_online_office",
"adobe_update",
"adp",
"adplex_media",
"adrive",
"adsafeprotected",
"adserverplus",
"adtech",
"adultadworld",
"adultfriendfinder",
"advection",
"adventori",
"advertising_com",
"advogato",
"aerserv",
"afl",
"afp",
"afreeca",
"africaguinee",
"afrikmag",
"aftenposten",
"aftonbladet",
"agame",
"ah",
"aiaigame",
"aib",
"aiccu_tic",
"aili",
"aim",
"aim_express",
"aim_transfer",
"aimini",
"aims",
"air_video",
"airaim",
"airkast",
"aizhan",
"akamai",
"akinator",
"akipress",
"akoam",
"aktuality",
"alakhbar",
"alaraby",
"alayam24",
"albawabhnews",
"alexa",
"alfajertv",
"alibaba",
"aliexpress",
"alimama",
"alipay",
"aljaras",
"aljarida",
"aljazeera",
"alkawnnews",
"all_slots_casino",
"allegro",
"allmusic",
"allocine",
"almanar",
"almashhad",
"almasryalyoum",
"alnilin",
"alquds",
"alrakoba",
"alsjl",
"altiris",
"alwafd",
"alwakeelnews",
"alwasatnews",
"alwatanvoice",
"alyamanalaraby",
"alyaoum24",
"amazon",
"amazon_adsystem",
"amazon_aws",
"amazon_chime",
"amazon_cloud_drive",
"amazon_mp3",
"amazon_music",
"amazon_video",
"ambebi",
"ameba",
"americanexpress",
"ami",
"amie_street",
"amjilt",
"ammonnews",
"ammyy_admin",
"amoebaos",
"amplitude",
"amqp",
"andornet",
"android_cnxmgr",
"angry_birds",
"animebw",
"animoto",
"anipang",
"annapurnapost",
"annonces",
"anobii",
"anspress",
"answers",
"ant1iwo",
"ants_p2p",
"any_0hop",
"anydesk",
"anz",
"anzhi",
"aol",
"aol_on",
"aol_one",
"apa",
"aparat",
"apns",
"apollo",
"apollo_lv",
"appbot",
"appchina",
"apple",
"apple_airplay",
"apple_airport",
"apple_airprint",
"apple_hls",
"apple_location",
"apple_maps",
"apple_music",
"apple_siri",
"apple_update",
"appledaily",
"applejuice",
"applovin",
"appnexus",
"appsflyer",
"appshopper",
"appstore",
"aprod",
"apsalar",
"aptoide",
"aqlame",
"arabiaweather",
"archive",
"arenabg",
"ares",
"areyouahuman",
"argaam",
"argus",
"aris",
"armorgames",
"armorgames_play",
"asana",
"asiae",
"asiandvdclub",
"ask",
"ask_fm",
"askcom",
"asmallworld",
"asproxy",
"atalk",
"athlinks",
"atlasinfo",
"atlassian",
"atlassolutions",
"att",
"atwiki",
"auction",
"audible",
"aufeminin",
"auone",
"auto24",
"autodesk",
"avas",
"avast",
"avatars_united",
"avaz",
"avg",
"avg_update",
"avira_update",
"avito_ma",
"avito_ru",
"avoidr",
"avto",
"awempire",
"ax25",
"axifile",
"azet",
"azetone",
"b92",
"babelgum",
"babycenter",
"babyhome",
"babylon",
"backpackers",
"badongo",
"badoo",
"baganmart",
"baidu",
"baidu_hi_games",
"baidu_maps",
"baidu_player",
"baidu_wallet",
"baike",
"balkanweb",
"banco_industrial",
"bancoestado",
"bancopopular",
"banesc_online",
"banglanews24",
"bankmellat",
"banvenez",
"baofeng",
"base",
"battlenet",
"bazaarvoice",
"bazos",
"bbc",
"bbc_player",
"bbm",
"bbm_audio",
"bbm_video",
"bbn_rcc_mon",
"bbs",
"bca_co",
"bd24live",
"bdjobs",
"bdnews24",
"beanfun",
"beatport",
"bebo",
"bebo_mail",
"beetalk",
"beforward",
"beirutpress",
"bemaniso",
"bernews",
"berniaga",
"bestsharing_com",
"bet365",
"bet9ja",
"bgp",
"bidorbuy",
"bidswitch",
"big5_sporting_goods",
"bigadda",
"bigeye",
"biglobe_ne",
"bigpond_movies",
"bigtent",
"bigupload",
"biip",
"bikhir",
"bild",
"bing",
"bint_jbeil",
"biobiochile",
"bitbucket",
"bitcoin",
"bitcomet_pex",
"bitdefender_update",
"bitenova",
"bithq",
"bitlord",
"bitme",
"bitmedianetwork",
"bitmetv",
"bits",
"bitseduce",
"bitshock",
"bitsoup",
"bitstrips",
"bittorrent",
"bittorrent_application",
"bittorrent_bundle",
"bitvaulttorrent",
"bitworld",
"bizographics",
"bjnp",
"blackberry",
"blackberry_locate",
"blackberry_update",
"blackplanet",
"blastingnews",
"bleacherreport",
"bleep",
"blic",
"blick",
"blip_tv",
"blockbuster",
"blocket",
"blog",
"blogdetik",
"blogfa",
"blogger",
"blogimg",
"blogphongthuy",
"blogspot",
"blogster",
"blokus",
"bloomberg",
"blubster",
"bluejayfilms",
"bluewin",
"bmff",
"bna",
"bofa",
"boldchat",
"bolha",
"bolt",
"bomb01",
"bondisk",
"bongacams",
"bonmarche",
"bonpoo",
"booking",
"books",
"books_iread",
"bootstrapcdn",
"bootytape",
"box_net",
"boxopus",
"br_sat_mon",
"braintree",
"branch",
"brazzers",
"brightcove",
"brightroll",
"brighttalk",
"browntracker",
"bsp",
"bssap",
"bt_bt",
"bt_chat",
"bt_dk",
"bt_wrzru",
"btjunkie",
"buddybuddy",
"bugs",
"bugsnag",
"bujumbura",
"bukalapak",
"bulawayo24",
"burt",
"businessweek",
"businessweekly",
"buzzfeed",
"buzzhand",
"buzznet",
"buzzsenegal",
"bwiza",
"bxml",
"bypassthat",
"caak",
"caasimadda",
"caf",
"cafemom",
"caliente",
"cam4",
"cameroon_info",
"campfire",
"camzap",
"canalrcn",
"candy_crush_saga",
"capitalone",
"carbonite",
"care2",
"cari",
"carsales",
"cartoonnetwork",
"cas",
"catchoftheday",
"caymannewsservice",
"cbs_video",
"cbt",
"ccp",
"ccproxy",
"cctv_vod",
"cdiscount",
"cdm",
"cdnetworks",
"cedexis",
"cellufun",
"central_torrent",
"centrum_cz",
"centrum_sk",
"cft",
"cftp",
"cgiproxy",
"cgmp",
"champion_football",
"channel4",
"channelmyanmar",
"chaos",
"chap",
"chat_on",
"chatroulette",
"cheetah_mobile",
"china_airlines",
"china_youth_league",
"chinacom",
"chinacomcn",
"chinadaily",
"chinanews",
"chinaren",
"chinatimes",
"chinaz",
"chosun",
"chosun_daily",
"chouftv",
"chrome_remote_desktop",
"chrome_update",
"cibercuba",
"cinemageddon",
"cip",
"citizentv",
"citrix_online",
"citrix_pvs",
"cj_mall",
"ck101",
"clarin",
"clash_of_clans",
"clasificadosonline",
"classmates",
"clearcase",
"clearspace",
"clicanoo",
"clicktale",
"clickyab",
"clien",
"clip",
"clip2net",
"cloob",
"cloudflare",
"cloudinary",
"cloudme",
"clubbox",
"clubic",
"clumsy_ninja",
"cnet",
"cnet_tv",
"cnm",
"cnn",
"cntv",
"cnyes",
"cnzz",
"coap",
"coccoc",
"cocolog_nifty",
"college_blender",
"comcast",
"comm",
"commbank",
"commentcamarche",
"comp",
"compaq_peer",
"concur",
"conduit",
"constantcontact",
"contentabc",
"conversant",
"conviva",
"coralcdn_user",
"corotos",
"corriere",
"cotp",
"couch_surfing",
"coupang",
"cpasbien",
"cphb",
"cpmstar",
"cpnx",
"crackle",
"craigslist",
"crashlytics",
"crazysaloon",
"crhoy",
"criteo",
"crittercism",
"crnobelo",
"crocko",
"crtp",
"crudp",
"cryptoheaven",
"cryptospout",
"crystalbet",
"csdn",
"cstrike",
"ctrip",
"cubadebate",
"cups",
"curapelanatureza",
"curse",
"cuteyhoneyflash",
"cv_online",
"cvbankas",
"cvs",
"cwseychelles",
"cyber12",
"cyberctm",
"cyworld",
"da7ye",
"dagbladet",
"daikynguyen",
"daily_booth",
"daily_pakistan",
"daily_strength",
"dailymail",
"dailymotion",
"dakaractu",
"dameware",
"dangdang",
"danishbits",
"dantri",
"dap_news",
"daraz",
"data_hu",
"daum",
"daummail",
"davidov",
"day",
"db2",
"dba",
"dbs",
"dccp",
"dcerpc",
"dcinside",
"dcn_meas",
"ddp",
"ddx",
"dealdey",
"dealfish",
"debian",
"debian_update",
"dec",
"decayenne",
"deepseek",
"deer_hunter_2014",
"deezer",
"defimedia",
"delfi",
"delicious",
"delta_search",
"depositfiles",
"derstandard",
"deskaway",
"destiny",
"detik",
"detiknews",
"deviant_art",
"dfs",
"dgp",
"dhcp",
"dhcp6",
"diameter",
"dianping",
"dict",
"digg",
"digikala",
"digitalriver",
"digitalverse",
"diino",
"dimp",
"diodeo",
"diop",
"diply",
"dir",
"directconnect",
"directdownloadlinks",
"directrev",
"directv",
"diretube",
"disaboom",
"discuss",
"disney_channel",
"disney_junior",
"disney_xd",
"distcc",
"divar",
"divshare",
"dmm_co",
"dnevnik",
"dnp3",
"dns",
"dns2tcp",
"dnshop",
"dnxlive",
"docstoc",
"docusign",
"doisongphapluat",
"dol2day",
"domain",
"donedeal",
"donga",
"dontstayin",
"doodle_jump",
"doorblog",
"dorgio",
"dostor",
"douban",
"doubleverify",
"douyu",
"dr",
"draugas",
"draugiem",
"drda",
"dreamora",
"dreamwiz",
"dropbox",
"dropbox_download",
"dropbox_upload",
"dropshots",
"druknet",
"drupal",
"dsi",
"dsr",
"dstv",
"dtls",
"dtp",
"dubizzle",
"duodecad_its",
"duowan",
"dv",
"dwarozh",
"dwtonline",
"dwu",
"dynamicintranet",
"e_boks",
"earthcam",
"earthlinktele",
"eastmoney",
"easytravel",
"ebay",
"ebay_classifieds",
"ebuddy",
"ecaytrade",
"echo",
"echoroukonline",
"ecuavisa",
"edgecast",
"edonkey",
"edu365",
"educarriere",
"egloos",
"egnyte",
"egp",
"eigrp",
"ekantipur",
"eksisozluk",
"ekskluziva",
"ekstrabladet",
"el_balad",
"el_nacional",
"elasticsearch",
"elblog",
"elbotola",
"elcat",
"elcomercio",
"eldeber",
"elfagr",
"elftown",
"elhawd",
"elheddaf",
"elheraldo",
"elhourriya",
"elkhadra",
"elle_tw",
"elluminate",
"elmogaz",
"elmundo",
"elnashra",
"elnoticiero",
"elnuevodia",
"elnuevodiario",
"elnuevoherald",
"elpais",
"elsalvador",
"eltiempo",
"eluniverso",
"elwatannews",
"emag",
"emansion_lr",
"emaps",
"emcon",
"emisoras_unidas",
"emol",
"emoo",
"empire_four_kingdoms",
"encap",
"encuentra24",
"energy_torrent",
"enip",
"ensighten",
"ensonhaber",
"eons",
"epa",
"epernicus",
"epl",
"epm",
"epom",
"eroom_net",
"eskimi",
"esnips",
"esp",
"espn",
"espncricinfo",
"essada",
"essaha",
"essahraa",
"essirage",
"established",
"estadio",
"etajakhabar",
"etao",
"etecsa",
"ethiojobs",
"ethiotube",
"etsi_li",
"ettoday",
"eve_online",
"everest_tech",
"evernote",
"everquest",
"evony",
"exacqvision",
"exblog",
"excel_online",
"exelate",
"expatriates",
"expedia",
"experience_project",
"exploroo",
"expressen",
"extremebits",
"extremenova",
"eyejot",
"eyny",
"ezfly",
"ezpeer",
"eztravel",
"facebook",
"facebook_apps",
"facebook_live",
"facebook_mail",
"facebook_messenger",
"facebook_video",
"facenama",
"faceparty",
"faces",
"facetime",
"fanpage",
"farmville",
"farsnews",
"fashionguide",
"fastly",
"fatakat",
"fatunetwork",
"fbcdn",
"fc2",
"fcm",
"feiliao",
"femina",
"fenopy",
"fetchtv",
"fetion",
"fetlife",
"fibre_channel",
"fijitimes",
"fijivillage",
"file_dropper",
"file_host",
"filefactory_com",
"fileflyer",
"fileguri",
"filei",
"filelist",
"filemail",
"filemaker_pro",
"filepost_ru",
"filer_cx",
"filer_net",
"filerio",
"files_to",
"filesanywhere",
"filesend_net",
"fileserve",
"filesharepro",
"filesovermiles",
"filestube",
"filetopia",
"fillos_de_galicia",
"filmaffinity",
"find_my_iphone",
"finn",
"fire",
"firefox_update",
"fix",
"flash",
"flashplugin_update",
"flashtalking",
"fledgewing",
"flickr",
"flipagram",
"flipboard",
"flipkart",
"flixster",
"flumotion",
"flurry",
"fluxiom",
"fly_proxy",
"flycell_ec",
"flycell_pe",
"fnb",
"fnu",
"fogbugz",
"foreningssparbanken",
"fortunechina",
"forum",
"fotki",
"fotolog",
"fotoweb",
"foursquare",
"foxbusiness",
"foxmovies",
"foxnews",
"foxsports",
"foxsports_au",
"foxtel",
"foxy",
"free",
"free_music_download",
"freebsd_update",
"freedomnewspaper",
"freeetv",
"freeloader",
"freemail",
"freenet",
"freeproxies",
"freetorrent",
"freewheel",
"freshnewsasia",
"friends_reunited",
"friendster",
"friendvox",
"fring",
"frostwire",
"fruhstuckstreff",
"fruit_ninja",
"fsecure",
"fsecure_update",
"ftp",
"ftp_data",
"ftps",
"fubar",
"funcaptcha",
"funshion",
"fuze_meeting",
"gabonreview",
"gadugadu",
"gaiaonline",
"game_center",
"gamebase_tw",
"gameloft",
"gamer_tw",
"gamerdna",
"games_co",
"gamesmomo",
"ganji",
"garaanews",
"garena",
"gather",
"gatherplace",
"gays",
"gazeta",
"gazetablic",
"gazetaexpress",
"gazzetta",
"gbridge",
"gcm",
"gcs",
"gdb_remote",
"geni",
"gerasanews",
"gettyimages",
"gfan",
"gfycat",
"ggp",
"ghanaweb",
"ghostsurf",
"gigacircle",
"gigasize_com",
"gigatribe",
"gigaup",
"giop",
"giops",
"giphy",
"github",
"gizmo",
"glide",
"globalpublishers",
"globo",
"glympse",
"gmail",
"gmail_basic",
"gmail_chat",
"gmail_drive",
"gmail_mobile",
"gmanetwork",
"gmarket",
"gmtp",
"gmw",
"gmx",
"gnunet",
"gnutella",
"go90",
"goal",
"gob",
"goboogy",
"godtube",
"gogo",
"gogobox",
"gogoyoko",
"gohappy",
"golden_village",
"goldenfrog",
"gomeetnow",
"gomtv_vod",
"goo_ne",
"goodreads",
"google",
"google_accounts",
"google_ads",
"google_analytics",
"google_appengine",
"google_cache",
"google_calendar",
"google_classroom",
"google_code",
"google_desktop",
"google_docs",
"google_earth",
"google_gen",
"google_groups",
"google_inbox",
"google_localguides",
"google_maps",
"google_photos",
"google_picasa",
"google_play",
"google_play_music",
"google_plus",
"google_safebrowsing",
"google_skymap",
"google_spaces",
"google_sprayscape",
"google_supl",
"google_tags",
"google_toolbar",
"google_translate",
"google_trusted_store",
"google_weblight",
"googlebot",
"goose",
"goplan",
"gossiplankanews",
"gotodevice",
"gotomeeting",
"gotomypc",
"gougou",
"gozambiajobs",
"granma",
"gratisindo",
"gravatar",
"gree",
"greenarea",
"grid",
"grono",
"groove",
"grooveshark",
"groupon",
"groupwise",
"gsshop",
"gstatic",
"gt_racing_2",
"gtalk",
"gtpv2",
"guampdn",
"guatevision",
"gudanglagu",
"guineenews",
"gulfup",
"gumtree",
"gyao",
"h225",
"h245",
"h248_binary",
"h248_text",
"habbo",
"haber7",
"halflife",
"hamachi",
"hamariweb",
"hambastagi",
"handycafe",
"hangame",
"hankooki",
"hankyung",
"hao123",
"haqqin",
"hardsextube",
"hardwarezone",
"hatena_ne",
"haveeru",
"hbo_go",
"hbonordic",
"heap",
"heavy",
"helpshift",
"heraldm",
"here",
"heroku",
"hespress",
"heureka",
"hexun",
"hgtv",
"hi5",
"hibapress",
"hidemyass",
"high_entropy",
"highwinds",
"hihi2",
"hinet_games",
"hip",
"hir24",
"hirufm",
"hirunews",
"hitbox",
"hk_observatory",
"hkgolden",
"hln",
"hmp",
"hockeyapp",
"hockeycurve",
"hola",
"hola_webproxy",
"honeywell_phd",
"hootsuite",
"hopopt",
"hospitality_club",
"host",
"hotfile",
"hotjar",
"hotline",
"hotspot_shield",
"hovrs",
"howcast",
"howstuffworks",
"hpellc",
"hs",
"hsbc",
"hsrp",
"http",
"http2",
"http_proxy",
"http_tunnel",
"https",
"huawei",
"huawei_update",
"hudong",
"huffington_post",
"hulu",
"hungrygowhere",
"hurriyet",
"hvg_hu",
"hyves",
"i2p",
"i_gamer",
"i_nlsp",
"i_part",
"iapp",
"iatp",
"iax",
"ibackup",
"ibay",
"ibibo",
"ibm_tealeaf",
"ica",
"icall",
"icap",
"iccp",
"icecast",
"icloud",
"icmp6",
"icq2go",
"icrt",
"icy",
"id_net",
"ident",
"idnes",
"idokep",
"idpr",
"idpr_cmtp",
"idrp",
"ifeng",
"ifeng_finance",
"ifile_it",
"ifilmtv",
"ifmp",
"ifolder_ru",
"igihe",
"igmp",
"igp",
"iheartradio",
"iiop",
"ikea",
"ikman",
"ikon",
"ikub",
"il",
"ilivid",
"iloveim",
"iltalehti",
"iltasanomat",
"imageshack",
"imap",
"imaps",
"imdb",
"imeem",
"imeet",
"imesh",
"imessage_file_download",
"imgur",
"iminent",
"imo",
"imp",
"impress",
"imvu",
"imyanmarhouse",
"inbox",
"incomplete",
"indaba_music",
"indeksonline",
"independent",
"index_hr",
"index_hu",
"indexexchange",
"indiatimes",
"indonetwork",
"indowebster",
"inewsmalta",
"infinity_blade_ii",
"infobae",
"informix",
"ing",
"inilah",
"inmobi",
"inneractive",
"innfrad",
"innovid",
"inquirer",
"instagram",
"intalking",
"interia",
"internations",
"internet_org",
"interpark",
"intuit",
"investigator",
"inwi",
"inyarwanda",
"iodine",
"ios_ota_update",
"ip_exp_1",
"ip_exp_2",
"ip_in_ip",
"ip_rdp",
"ip_reserved",
"ipcomp",
"ipcp",
"ipcv",
"iperf",
"iplt",
"ipp",
"ippc",
"ipsec",
"iptm",
"ipv6cp",
"ipx_in_ip",
"ipxrip",
"ipxsap",
"iqiyi",
"irc",
"irc_galleria",
"irc_transfer",
"ircs",
"irctc",
"irods",
"irtp",
"isakmp",
"iscsi",
"isis",
"isl",
"iso_ip",
"iso_tp4",
"issuu",
"isup",
"italki",
"itsmy",
"itsup",
"itunes",
"itv_player",
"iwarp",
"iwiw",
"ja",
"jabber",
"jabber_transfer",
"jaiku",
"jajah",
"jamaica_gleaner",
"jamaicaobserver",
"jamiiforums",
"jammerdirect",
"jango",
"jap",
"jasmin",
"java_rmi",
"java_update",
"javedch",
"javhd",
"jawabkom",
"jawharafm",
"jedi",
"jetaoshqef",
"jetdirect",
"jfranews",
"jibjab",
"jingdong",
"jira",
"jne",
"jobs_af",
"jobs_bg",
"jobsdb",
"jobstreet",
"jofogas",
"joongang_daily",
"joq",
"jquery",
"jubii",
"jumia",
"junkmail",
"justin_tv",
"jutarnji",
"jxta",
"kaieteurnewsonline",
"kaioo",
"kaixin_chat",
"kajgana",
"kakaku",
"kakaocdn",
"kakaostory",
"kakaotalk",
"kalerkantho",
"kankan",
"kapanlagi",
"kapook",
"karosgame",
"kaskus",
"kaspersky",
"kaspersky_update",
"kasvyksta",
"kazaa",
"kb_bank",
"kbn_live",
"kbs",
"kbstar",
"keezmovies",
"kemenkumham",
"khaberni",
"khan",
"khmer_news",
"khmer_note",
"khmer_press",
"khmeread",
"khmerload",
"kickasstorrents",
"kigalitoday",
"kijiji",
"kik",
"king",
"kingdomxxx",
"kino",
"kinogo",
"kiwibox",
"klikbca",
"klix",
"koha",
"kohsantepheapdaily",
"kolektiv",
"kompas",
"kompasiana",
"konaminet",
"konga",
"koolim",
"kooora",
"kpasswd",
"kproxy",
"krb5",
"krux",
"kryptolan",
"kstna",
"ku6",
"kuenselonline",
"kugou",
"kundo",
"kupujemprodajem",
"kurir",
"kurir_info",
"kuxun",
"kwejk",
"laacibnet",
"labanquepostale",
"lady8844",
"lajmi",
"lan",
"lanacion",
"lankadeepa",
"lanshark",
"lapagina",
"lapatilla",
"laposte_webmail",
"laprensa",
"laprensagrafica",
"laredoute",
"larp",
"lastfm",
"lastpass",
"lativ",
"lava_lava",
"lazada",
"lcp",
"ldap",
"ldaps",
"ldblog",
"le360",
"leaf_1",
"leaf_2",
"leapfile",
"leboncoin",
"lefaso",
"lent",
"leral",
"leteckaposta_cz",
"letv",
"level3",
"lexpress",
"lg_eshop",
"libero_video",
"libjingle_pseudotcp",
"librarything",
"lider_bet",
"life",
"lifeknot",
"liftoff",
"ligatus",
"lightstreamer",
"line",
"line_games",
"line_wind_runner",
"lineage2",
"linio",
"linkedin",
"lintasberita",
"lionair",
"liontravel",
"liputan6",
"list_am",
"listindiario",
"listografy",
"live_groups",
"live_hotmail",
"live_meeting",
"live_mesh",
"live_storage",
"livechat",
"livedoor",
"liveinternet",
"livejournal",
"livemail_attach",
"livemail_mobile",
"livemocha",
"liveperson",
"liverail",
"livescore",
"livingsocial",
"lkqd",
"llnwd",
"llp",
"load_to",
"loadbalan",
"localytics",
"logmein",
"logmein_rescue",
"lokalisten",
"lookout_ms",
"loop",
"looppng",
"lotame",
"lotour",
"lotte",
"lotterypost",
"lotus_live",
"lotus_sametime",
"lotusnotes",
"lpr",
"lqr",
"lrytas",
"ltn",
"ltt",
"luke",
"lun",
"lunarstorm",
"lusakatimes",
"lvping",
"lync",
"lync_online",
"lynda",
"m2pa",
"m2ua",
"m3ua",
"maaii",
"maannews",
"magicjack",
"magumagu",
"mail2000",
"mail_189",
"mail_ru_games",
"mail_ru_love",
"mail_ru_moimir",
"mail_ru_webagent",
"mailru",
"mailru_agent",
"mako",
"maktoob",
"malformed",
"malijet",
"maliweb",
"maltapark",
"maltatoday",
"mana",
"mandriva_update",
"manet",
"mangocity",
"mangvieclam",
"manolito",
"manoramaonline",
"manx",
"mapbox",
"mapi",
"mapquest",
"mapy",
"marca",
"marebpress",
"marktplaats",
"mashable",
"mashare",
"match",
"maxcdn",
"maybank2u",
"mbc",
"mbl",
"mbn",
"mcafee",
"mcb_home",
"mcs",
"mebc",
"media_innovation_group",
"mediacongo",
"mediafire",
"mediamath",
"meerkat",
"meetin",
"meetingplace",
"meetme",
"meettheboss",
"meetup",
"meevee",
"mega",
"megaproxy",
"megashares_com",
"megaupload",
"megavideo",
"meituan",
"mekusharim",
"mendeley",
"menstylefashion",
"mercadolibre",
"mercador",
"merit_inp",
"merojax",
"merrjep",
"messengerfx",
"metacafe",
"mfe_nsp",
"mgcp",
"mgid",
"mgoon",
"miaopai",
"mibbit",
"micp",
"microsoft",
"mihaaru",
"mihanblog",
"mihanwebads",
"mikogo",
"milad",
"milanuncios",
"millardayo",
"milli",
"milliyet",
"mimp",
"minecraft_pocket",
"mingpao",
"minuto30",
"mipv6",
"miro",
"mistreci",
"mitalk",
"mixi",
"mixpanel",
"mk",
"mmm_nigeria",
"mms",
"mms_iso",
"mmse",
"moat",
"mobage",
"mobfox",
"mobile",
"mobile01",
"mobile_me",
"mobilehdr",
"mobilemarket",
"mobilink",
"mocean",
"mocospace",
"modbus",
"moe_gov",
"mog",
"mogulus",
"moi_qatar",
"momoshop",
"monex",
"money_163",
"moneydj",
"monitor",
"monster",
"moov",
"mop",
"mopub",
"morefreecamsecrets",
"mosaiquefm",
"motika",
"motinews",
"mount",
"mouthshut",
"mover",
"movie2free",
"movitel",
"mozilla",
"mozzi",
"mp3_rocket",
"mp3teca",
"mpegts",
"mpls_in_ip",
"mplus_messenger",
"mpquest",
"mq",
"mqtt",
"ms_communicator",
"ms_onenote",
"ms_planner",
"ms_sway",
"ms_translator",
"msn",
"msn_groups",
"msn_search",
"msn_video",
"msnmobile",
"msrp",
"msrpc",
"mt",
"mtn",
"mtp",
"mtv",
"mubi",
"mudah",
"muhitelyemen",
"multiply",
"multiupload",
"musica",
"musicchoice",
"mute",
"mux",
"muxlim",
"mxit",
"my_com",
"my_opera",
"my_talking_tom",
"my_yahoo",
"myanimelist",
"myanmarload",
"myauto",
"mychurch",
"mydiv",
"mydownloader",
"mydrive",
"myheritage",
"myjoyonline",
"mylife",
"mymarket",
"myoptus",
"mypeople_messenger",
"mypocket",
"myspace",
"myspace_video",
"mysql",
"mystart",
"myvideo",
"myway",
"mywebsearch",
"myyearbook",
"nabluslive",
"nablustv",
"nacion",
"nagariknews",
"naij",
"nairaland",
"namba",
"namibian",
"namu",
"napster",
"narp",
"nasa",
"nasza_klasa",
"nat_pmp",
"nate_mail",
"natecyworld",
"nation",
"nationalgeographic",
"nationallottery",
"nationnews",
"nauta",
"naver",
"naver_blog",
"naver_mobile",
"naverdrive",
"navermail",
"nba",
"nba_china",
"nbc",
"nbns",
"ncaa",
"ncore",
"ncp",
"ndmp",
"nduoa",
"nefsis",
"nefsys",
"nend",
"neobux",
"net",
"net_proxy",
"netblt",
"netbsd_update",
"netflix",
"netflow",
"neti",
"netload",
"netlog",
"netmarble",
"netmeeting_ils",
"netperform",
"nettby",
"neulion",
"new_relic",
"news24",
"news24nepal",
"news784",
"news_am",
"news_au",
"news_mn",
"newsbook",
"newsday",
"newsit",
"newvision",
"nexian",
"nexon",
"nexopia",
"nextmedia",
"nfl",
"nfs",
"nfs4",
"ngo_post",
"ngrok",
"nhadatso",
"niconico_douga",
"nielsen",
"nieuwsblad",
"nifty",
"nigeremploi",
"nike",
"nikkei",
"nimbuzz_web",
"ning",
"nintendo",
"njuskalo",
"nlockmgr",
"nlsp",
"nntp",
"nntps",
"noa",
"nod32_update",
"nokia",
"nokia_ovi",
"nonghyup_bank",
"nordea",
"norton_update",
"noticias24",
"novinky",
"nownews",
"nrdp",
"nrk",
"nrl",
"nrpe",
"nrttv",
"nsfnet_igp",
"nsh",
"nspi",
"ntd",
"ntp",
"ntv",
"ntvbd",
"nu",
"nuomi",
"nur",
"nust",
"nvp_ii",
"nyasatimes",
"nydailynews",
"nytimes",
"nzherald",
"ocs",
"ocsp",
"octopz",
"octoshape",
"odnoklassniki",
"odsiebie_najlepsze_net",
"office365",
"office_docs",
"officedepot",
"offnews",
"oicq",
"okcupid",
"okezone",
"okta",
"okwave",
"olark",
"olx",
"onclickads",
"oneclimate",
"onedio",
"onedrive",
"onef_bf",
"onehub",
"onelife",
"onet",
"oneworld_org",
"oneworldtv",
"onlinedown",
"onlinekhabar",
"onliner",
"onlive",
"ontests",
"oovoo",
"ooyala",
"opcua",
"open_diary",
"openbsd_update",
"openft",
"opengw",
"openrice",
"openrtb",
"opensooq",
"openstreetmap",
"openvpn",
"openx",
"opera_mobile_store",
"opera_update",
"oppetarkiv",
"optimizely",
"optus",
"oracle",
"oracle_rac",
"orange",
"orangemail",
"orb",
"orf",
"oriental_daily",
"origjinale",
"origo",
"orkut",
"osinl",
"ospf",
"ouedkniss",
"outbrain",
"outeverywhere",
"outlook",
"ovaciondigital",
"over_blog",
"owa",
"ows",
"oxu",
"padabum",
"paipai",
"paltalk",
"paltalk_audio",
"paltalk_transfer",
"paltalk_video",
"palweather",
"panda_update",
"pando",
"pandora",
"pandora_tv",
"panet",
"panoramio",
"pantip",
"pap",
"paraguay",
"paran",
"parse",
"partis",
"partnerup",
"party_poker",
"passportstamp",
"pastebin",
"pastebin_posting",
"path",
"payeasy",
"paypal",
"pazar3",
"pbx",
"pcanywhere",
"pcgames",
"pchome",
"pclady",
"pcloud",
"pconline",
"pd_proxy",
"peacefmonline",
"peercast",
"peerguardian",
"pengyou",
"people",
"perfect_dark",
"perforce",
"perform",
"perfspot",
"periscope",
"persianblog",
"petitesannonces",
"peyvandha",
"pgm",
"philenews",
"photobucket",
"phproxy",
"phweet",
"pi_af",
"pi_data",
"pichat",
"pik",
"pim",
"pimang",
"pingsta",
"pinterest",
"piolet",
"pipe",
"pixiv",
"pixnet",
"plants_vs_zombies",
"plaxo",
"playahead",
"playstation",
"plentyoffish",
"plius",
"plurk",
"pmhotnews",
"pnni",
"poco",
"pogo",
"point",
"pokemon_go",
"poker_stars",
"pole_emploi",
"politis_news",
"pop3",
"pop3s",
"popads",
"porn555",
"pornhub",
"pornsurvey",
"portalanalitika",
"portmap",
"postgres",
"postimees",
"pou",
"power_bi",
"powerpoint_online",
"ppfilm",
"pplive",
"ppomppu",
"pps",
"ppstream",
"pptp",
"pptv",
"prensa",
"prensalibre",
"present",
"press24",
"pressan",
"priceminister",
"pricerunner",
"primewire",
"print_io",
"private_enc",
"privax",
"prm",
"prodavalnik",
"profinet",
"pronto",
"propertyguru",
"prothom_alo",
"protothema",
"proxeasy",
"proxono",
"psiphon",
"psn",
"psyonix",
"ptp",
"public",
"public_lu",
"publinews",
"pubmatic",
"puls24",
"pulse_com_gh",
"pulsepoint",
"punyumunyu",
"pup",
"putlocker",
"puzzle_and_dragon",
"pvp",
"q931",
"qapacity",
"qatarairways",
"qatarliving",
"qik_video",
"qiniu",
"qnx",
"qoo10",
"qq",
"qq_blog",
"qq_dancer",
"qq_finance",
"qq_games",
"qq_lady",
"qq_mail",
"qq_news",
"qq_r2",
"qq_speed",
"qq_transfer",
"qq_web",
"qq_weibo",
"qqdownload",
"qqlive",
"qqmusic",
"qqstream",
"qqvideo",
"qtrax",
"quake",
"quantcast",
"quantum_dxi_ost",
"quarterlife",
"quic",
"quickflix",
"quizup",
"qunar",
"qvod",
"qzone",
"r10",
"rackspace",
"radiko",
"radio1",
"radio_bethlehem_2000",
"radiookapi",
"radiumone",
"radius",
"radiusim",
"radmin",
"rainbow",
"rakuten",
"ramallah",
"rambler",
"rambler_webmail",
"ranap",
"rapidshare",
"rapidupload_com",
"rappler",
"ratopati",
"raulken",
"ravelry",
"raya",
"rayfile",
"rcsc",
"rdp",
"rdt",
"realestate",
"realtor",
"reddit",
"redhat_update",
"redtube",
"reflected_networks",
"reklama5",
"renren",
"repubblica",
"republika",
"republika_slovenija",
"researchgate",
"retroshare",
"reuters",
"revcontent",
"reverbnation",
"reverso",
"revolico",
"rfb",
"rhapsody",
"ricardo",
"riffsy",
"rimnow",
"ringring",
"rip1",
"rip2",
"ripng1",
"rlcdn",
"rlogin",
"rlp",
"rmi_iiop",
"rmix",
"rmvbusters",
"roboform",
"rocket_league",
"rogers",
"rohc",
"rolloid",
"rollout",
"rovi",
"rovio",
"royalgazette",
"royanews",
"rozetka",
"rpc",
"rpl",
"rquota",
"rsh",
"rss",
"rstat",
"rsvp",
"rsvp_e2e_ignore",
"rsync",
"rt",
"rtcp",
"rtl",
"rtmp",
"rtp",
"rtsp",
"rtvslo",
"rubiconproject",
"rudaw",
"runescape",
"rusers",
"ruten",
"rutracker",
"ruv",
"rvd",
"ryanair",
"ryze",
"s1ap",
"s_oman",
"saavn_music",
"sabah",
"sabameeting",
"sabay",
"saberindo",
"sabq",
"safaricom",
"safewebonline",
"sahafah",
"saharamedias",
"sahibinden",
"saitebi",
"sakura_ne",
"salamnews",
"salesforce",
"salesforce_chatter",
"samanews",
"sameerbook",
"samsung",
"samsung_apps",
"samsung_update",
"sana",
"sanjesh",
"sanook",
"sap",
"sapo",
"sarahanews",
"sarayanews",
"sat_expak",
"sat_mon",
"savefile_com",
"savefrom",
"sayclub",
"sbs",
"sbs_au",
"scc_sp",
"sccm",
"sccp",
"sccp_ss7",
"scenehd",
"scheduled_tp",
"sciencestage",
"scispace",
"scorecardresearch",
"scotiabank",
"scps",
"scribd",
"sde",
"sdo",
"sdrp",
"searchnu",
"secondlife",
"secure_vmtp",
"seeqpod",
"seesaa",
"seesmic",
"segye",
"sekindo",
"sendspace",
"senego",
"seneweb",
"seoul_news",
"setopati",
"seznam",
"sfr",
"sgcarmart",
"shabiba",
"shaparak",
"share",
"sharebee_com",
"sharebox",
"sharepoint",
"sharepoint_admin",
"sharepoint_blog",
"sharepoint_calendar",
"sharepoint_document",
"sharepoint_online",
"sharereactor",
"sharethemusic",
"sharethrough",
"shasha",
"shazam",
"shekulli",
"shelfari",
"shim6",
"shinhan",
"shobiddak",
"shop_com_mm",
"shoutcast",
"showmypc",
"showtime_anytime",
"shqiperiaime",
"shutterfly",
"shutterstock",
"siebel_crm",
"sigmalive",
"signal",
"signal_private_messenger",
"silverlight",
"simperium",
"simple_msg_p",
"simpleupload_net",
"sina",
"sina_blog",
"sina_finance",
"sina_news",
"sina_video",
"sina_webmail",
"sina_weibo",
"sinoptik",
"siol",
"sip",
"sip_soap",
"sistic",
"sitel",
"sizmek",
"skee_ball_arcade",
"skelbiu",
"skip",
"skroutz",
"sky",
"sky_player",
"skyblog",
"skycn",
"skydrive",
"skydrive_login",
"skynewsarabia",
"skype",
"skyrock",
"slack",
"slacker",
"slando",
"sld",
"slideshare",
"slingbox",
"slsk",
"sm",
"smaato",
"smartadserver",
"smartalk",
"smb",
"smb_direct",
"sme",
"smh",
"smpp",
"smtp",
"smtps",
"sna",
"snapchat",
"snmp",
"snp",
"snpp",
"soap",
"socialcam",
"socialtv",
"socialvibe",
"socks2http",
"socks4",
"socks5",
"soft4fun",
"softbank",
"softonic",
"softros_messenger",
"sogou",
"sohu",
"sohu_blog",
"soku",
"solarwinds",
"somalijobs",
"somon",
"somud",
"sonet_ne",
"sonico",
"sonmp",
"sonobi",
"sopcast",
"sophos_update",
"soribada",
"soso",
"soufun",
"soundcloud",
"souq",
"sourceforge",
"southwest",
"soy502",
"sp",
"spdy",
"speedtest",
"spid",
"spiegel",
"splunk",
"sportal",
"sportchosun",
"sportpesa",
"sportsillustrated",
"sportsseoul",
"spotflux",
"spotify",
"spotxchange",
"spredfast",
"sprint",
"sprite_rpc",
"sps",
"spynet",
"sqli",
"squirrelmail",
"srp",
"srvloc",
"ss",
"sscopmce",
"ssdp",
"ssh",
"ssl",
"st",
"st_lucia_news_online",
"stackexchange",
"stackoverflow",
"stafaband",
"stagevu",
"standardmedia",
"starnieuws",
"startimes",
"state_bank_of_india",
"stayfriends",
"stealthnet",
"steam",
"stick_cricket",
"stickam",
"stickyads",
"stockq",
"storytel",
"streamaudio",
"streamrail",
"studivz",
"stuff",
"stumbleupon",
"stun",
"stupid_videos",
"sua",
"subway_surfers",
"sugar_crm",
"sugar_sync",
"sugklonistiko",
"sulit",
"sun_nd",
"sun_online",
"suning",
"super",
"super_mario_run",
"supercell",
"suppersoccer",
"suresome",
"surrogafier",
"surveymonkey",
"svcctl",
"svn",
"svtplay",
"swedbank",
"swepiracy",
"swipe",
"switch_concepts",
"sybase",
"symantec",
"sync",
"synflood",
"syri",
"syslog",
"t38",
"t_online",
"tabelog",
"taboola",
"tacacs_plus",
"tagged",
"tagoo",
"tahiti_infos",
"taiwanlottery",
"tajfile",
"takealot",
"taku_file_bin",
"talabat",
"talenttrove",
"talkbiznow",
"taltopia",
"tamilthunder_com",
"tamtaminfo",
"tango",
"tanx",
"taobao",
"tapatalk",
"tapchisao",
"taqadoumi",
"taringa",
"tasweernews",
"tawary",
"tayara",
"tayyar",
"tbs",
"tcf",
"tchatche",
"tcp_over_dns",
"tds",
"teachertube",
"teachstreet",
"teads",
"tealium",
"teamspeak",
"teamspeak_v3",
"teamviewer",
"tebyan",
"techinline",
"telegraaf",
"telegraf",
"telegrafi",
"telegram",
"telestream",
"teletica",
"telnet",
"telnets",
"teltel",
"tempointeraktif",
"tencent",
"teredo",
"tf1",
"tftp",
"tgbus",
"thadinatin",
"the_auteurs",
"the_simpsons_tapped_out",
"the_star",
"theladbible",
"themasports",
"thepiratebay",
"thethao247",
"thevideos",
"think",
"thithtoolwin",
"three",
"threema",
"thunder",
"ti_les_twra",
"tianya",
"tibcordv",
"ticketmonster",
"tidal",
"tidaltv",
"tiempo",
"tigerair",
"time",
"timesofmalta",
"timesofoman",
"tinder",
"tistory",
"tlsp",
"tmall",
"tn8",
"tns",
"tntdrama",
"tnvip",
"to_mati",
"tocmai",
"toggle",
"tokbox",
"tokobagus",
"tokopedia",
"tonaton",
"top_channel",
"topfmradio",
"topky",
"topvideo",
"topvldeo",
"tor",
"tor2web",
"torg",
"tori",
"torrent9",
"torrentdownloads",
"torrentkim5",
"torrentz",
"tothemaonline",
"touch",
"tower_of_saviors",
"tp_plus_plus",
"trackingclick",
"trademe",
"trafficfactory",
"trafficjunky",
"transferbigfiles_com",
"travbuddy",
"travellerspoint",
"travelocity",
"travian",
"trend",
"trendmicro_update",
"tribe",
"tribunnews",
"trinidadexpress",
"trinituner",
"trippy",
"trombi",
"trunk_1",
"trunk_2",
"truste",
"ts",
"ttp",
"tu",
"tube8",
"tubemogul",
"tuberel",
"tudou",
"tuenti",
"tukif",
"tuko",
"tumblr",
"tune",
"tune_inc",
"tunein",
"tunewiki",
"tunigate",
"tunisia_sat",
"turbo",
"turbobit",
"turn",
"turner",
"tut",
"tv",
"tv2",
"tv3",
"tv4play",
"tvants",
"tvcatchup",
"tvking",
"tvm",
"tvn_noticias",
"tvnet",
"tvuplayer",
"twipple",
"twitch",
"twitpic",
"twitter",
"twoo",
"txxx",
"uaudp",
"uaudp_rtp",
"uber",
"ubuntu",
"ubuntu_one",
"ucoz",
"ucp",
"udn",
"udplite",
"ukr",
"ukwezi",
"ulp",
"ultimahora",
"ultrashare_net",
"ultrasurf",
"umac",
"umeng",
"umuryango",
"umuseke",
"unamexico",
"unamibia",
"unassigned_ip_prot_143",
"unassigned_ip_prot_144",
"unassigned_ip_prot_145",
"unassigned_ip_prot_146",
"unassigned_ip_prot_147",
"unassigned_ip_prot_148",
"unassigned_ip_prot_149",
"unassigned_ip_prot_150",
"unassigned_ip_prot_151",
"unassigned_ip_prot_152",
"unassigned_ip_prot_153",
"unassigned_ip_prot_154",
"unassigned_ip_prot_155",
"unassigned_ip_prot_156",
"unassigned_ip_prot_157",
"unassigned_ip_prot_158",
"unassigned_ip_prot_159",
"unassigned_ip_prot_160",
"unassigned_ip_prot_161",
"unassigned_ip_prot_162",
"unassigned_ip_prot_163",
"unassigned_ip_prot_164",
"unassigned_ip_prot_165",
"unassigned_ip_prot_166",
"unassigned_ip_prot_167",
"unassigned_ip_prot_168",
"unassigned_ip_prot_169",
"unassigned_ip_prot_170",
"unassigned_ip_prot_171",
"unassigned_ip_prot_172",
"unassigned_ip_prot_173",
"unassigned_ip_prot_174",
"unassigned_ip_prot_175",
"unassigned_ip_prot_176",
"unassigned_ip_prot_177",
"unassigned_ip_prot_178",
"unassigned_ip_prot_179",
"unassigned_ip_prot_180",
"unassigned_ip_prot_181",
"unassigned_ip_prot_182",
"unassigned_ip_prot_183",
"unassigned_ip_prot_184",
"unassigned_ip_prot_185",
"unassigned_ip_prot_186",
"unassigned_ip_prot_187",
"unassigned_ip_prot_188",
"unassigned_ip_prot_189",
"unassigned_ip_prot_190",
"unassigned_ip_prot_191",
"unassigned_ip_prot_192",
"unassigned_ip_prot_193",
"unassigned_ip_prot_194",
"unassigned_ip_prot_195",
"unassigned_ip_prot_196",
"unassigned_ip_prot_197",
"unassigned_ip_prot_198",
"unassigned_ip_prot_199",
"unassigned_ip_prot_200",
"unassigned_ip_prot_201",
"unassigned_ip_prot_202",
"unassigned_ip_prot_203",
"unassigned_ip_prot_204",
"unassigned_ip_prot_205",
"unassigned_ip_prot_206",
"unassigned_ip_prot_207",
"unassigned_ip_prot_208",
"unassigned_ip_prot_209",
"unassigned_ip_prot_210",
"unassigned_ip_prot_211",
"unassigned_ip_prot_212",
"unassigned_ip_prot_213",
"unassigned_ip_prot_214",
"unassigned_ip_prot_215",
"unassigned_ip_prot_216",
"unassigned_ip_prot_217",
"unassigned_ip_prot_218",
"unassigned_ip_prot_219",
"unassigned_ip_prot_220",
"unassigned_ip_prot_221",
"unassigned_ip_prot_222",
"unassigned_ip_prot_223",
"unassigned_ip_prot_224",
"unassigned_ip_prot_225",
"unassigned_ip_prot_226",
"unassigned_ip_prot_227",
"unassigned_ip_prot_228",
"unassigned_ip_prot_229",
"unassigned_ip_prot_230",
"unassigned_ip_prot_231",
"unassigned_ip_prot_232",
"unassigned_ip_prot_233",
"unassigned_ip_prot_234",
"unassigned_ip_prot_235",
"unassigned_ip_prot_236",
"unassigned_ip_prot_237",
"unassigned_ip_prot_238",
"unassigned_ip_prot_239",
"unassigned_ip_prot_240",
"unassigned_ip_prot_241",
"unassigned_ip_prot_242",
"unassigned_ip_prot_243",
"unassigned_ip_prot_244",
"unassigned_ip_prot_245",
"unassigned_ip_prot_246",
"unassigned_ip_prot_247",
"unassigned_ip_prot_248",
"unassigned_ip_prot_249",
"unassigned_ip_prot_250",
"unassigned_ip_prot_251",
"unassigned_ip_prot_252",
"unegui",
"universiti_brunei_darussalam",
"university_of_botswana",
"univision",
"unknown",
"unruly",
"uol",
"upload_com",
"uploaded_net",
"uploading",
"uploadingit_com",
"uplynk",
"uptobox",
"uptodown",
"urbanairship",
"urdupoint",
"usabit_com",
"usatoday",
"usbmux",
"usejump",
"usp",
"ustream",
"uti",
"utorrent",
"utp",
"uusee",
"uwi",
"uz_ac",
"v5ua",
"vaguthu",
"vakaka",
"vampirefreaks",
"vanguardngr",
"varzesh3",
"vbox7",
"vecer",
"vecernji",
"vector",
"veetle",
"veohtv",
"verizon",
"vertamedia",
"vestniktm",
"vetogate",
"vevo",
"vg",
"viadeo",
"viaplay",
"viber",
"videobash",
"videojug",
"videoplaza",
"videosurf",
"videosz",
"vidmax",
"vidme",
"vidyard",
"vietbao",
"viewpath",
"viewster",
"vijesti",
"vimeo",
"vine",
"vines",
"visa",
"visa_checkout",
"visadd",
"visir",
"vivanews",
"vjc_comp",
"vjc_uncomp",
"vkontakte",
"vmotion",
"vmtp",
"vmware",
"vmware_horizon_view",
"vnetip",
"vnexpress",
"voddler",
"vox",
"vpnoverdns",
"vrrp",
"vsee",
"vtun",
"vtunnel",
"vtv",
"vube",
"vuiviet",
"vuze",
"vyew",
"vz_lt",
"wada",
"wakoopa",
"walla",
"wallstreetjournal_china",
"walmart",
"wamba",
"wandoujia",
"wapa",
"wasabi",
"washingtonpost",
"wat",
"wattan",
"wayn",
"waze",
"wb_expak",
"wb_mon",
"wccp",
"weather",
"weather2umbrella",
"weather4all",
"web",
"web_crawler",
"web_de",
"webbiographies",
"webex",
"webex_weboffice",
"weborama",
"websocket",
"webtretho",
"wechat",
"weiphone",
"wellsfargo",
"weourfamily",
"werkenntwen",
"wesp",
"westpac",
"wetransfer",
"wfc",
"whatsapp",
"whois",
"wiiconnect24",
"wikia",
"wikipedia",
"willhaben",
"wimp",
"winamax",
"windows_azure",
"windows_marketplace",
"windows_update",
"windowslive",
"windowslivespace",
"windowsmedia",
"winmx",
"winny",
"wins",
"wiserearth",
"wix",
"wixi",
"wooribank",
"word_online",
"wordpress",
"worksite",
"wow",
"wp",
"wretch",
"wrike",
"wsman",
"wsn",
"wsop",
"wsp",
"wtls",
"wtp",
"wtv",
"x11",
"x25",
"xanga",
"xbox",
"xbox_music",
"xbox_video",
"xboxlive",
"xboxlive_marketplace",
"xcams",
"xcap",
"xdmcp",
"xendan",
"xfs",
"xhamster",
"xiami",
"xiaomi",
"xing",
"xinhuanet",
"xinnet",
"xiph",
"xl",
"xl_nonton",
"xl_wap",
"xl_webmail",
"xl_webportal",
"xlnet",
"xlovecam",
"xm_radio",
"xmcp",
"xmlrpc",
"xnet",
"xns",
"xns_idp",
"xnxx",
"xopom",
"xot",
"xrea",
"xt3",
"xtp",
"xuite",
"xvideos",
"xvideoslive",
"xyplex",
"y8",
"yadro",
"yahoo",
"yahoo360plusvietnam",
"yahoo_answers",
"yahoo_biz",
"yahoo_buy",
"yahoo_douga",
"yahoo_games",
"yahoo_geocities",
"yahoo_groups",
"yahoo_korea",
"yahoo_maps",
"yahoo_realestate",
"yahoo_screen",
"yahoo_search",
"yahoo_stock_tw",
"yahoo_travel",
"yallakora",
"yam",
"yammer",
"yandex",
"yandex_disk",
"yandex_fotki",
"yandex_maps",
"yandex_music",
"yandex_video",
"yandex_webmail",
"yapo",
"yasour",
"yelp",
"yemen_net",
"yemennow",
"yen",
"yesky",
"yieldmanager",
"yieldmo",
"yihaodian",
"yle",
"ymail2",
"ymail_classic",
"ymail_mobile",
"ymail_mobile_new",
"ymsg",
"ymsg_conf",
"ymsg_transfer",
"ymsg_video",
"ymsg_webmessenger",
"ynet",
"yodiz",
"yoka",
"yomiuri",
"yoono",
"youdao",
"youku",
"youm7",
"youmeo",
"youni",
"younow",
"youporn",
"your_freedom",
"yourfilehost",
"yourfiles_biz",
"youseemore",
"yousendit",
"youtube",
"youtube_hd",
"ypbind",
"yppasswd",
"ypserv",
"ypupdate",
"yr",
"ytimg",
"yugma",
"yuuguu",
"zabbix_agent",
"zahraa",
"zalo",
"zaluu",
"zambiawatchdog",
"zamunda",
"zattoo",
"zedo",
"zelune",
"zendesk",
"zenmate",
"zeri",
"zhihu",
"ziddu",
"zimbra",
"zimbra_standard",
"zimeye",
"zing",
"zippyshare",
"zoho",
"zoho_crm",
"zoho_db",
"zoho_im",
"zoho_meeting",
"zoho_notebook",
"zoho_people",
"zoho_planner",
"zoho_share",
"zoho_sheet",
"zoho_show",
"zol",
"zombie_tsunami",
"zone_telechargement",
"zonealarm_update",
"zoo",
"zoom",
"zoomtanzania",
"zopim",
"zougla",
"zoznam",
"zshare",
"zuji",
"zum",
"zumodrive",
"zwherald",
"zynga",
]


# === Code ===

def getdesc(app, name, deprecated):
    # ASCII encode/decode strips out unicode
    # rstrip removes trailing dot
    desc = app["desc_str"]["en"].encode('ascii', 'ignore').decode('ascii').rstrip('.')

    # --- Deprecation ---

    deprecated[name] = app["deprecated"]

    if name.startswith("unassigned_ip_prot_"):
        deprecated[name] = "true"

    # Deprecation check.
    if ("Deprecated" in desc or "deprecated" in desc or "replaced by" in desc or "shut down" in desc or "closed on" in desc or "replaced by" in desc) and not deprecated[name]:
        print("Should be deprecated? : ("+name+") <<"+desc+">>")

    if (deprecated[name]):
        desc = "(Deprecated) "+desc

    # Must do these replaces before the partition
    desc = desc.replace('music. chat', 'music, chat')
    desc = desc.replace('IEC 60870-6/TASE.2. Inter-Control', 'IEC 60870-6/TASE.2 Inter-Control')
    desc = desc.replace('Inc. ', 'Inc ')

    # parser.unescape replaces &quot &amp etc.
    # rstrip removes trailing whitespace
    # partition grabs only the first sentence
    parser = HTMLParser()
    desc = parser.unescape(desc.rstrip().partition(". ")[0])

    # --- Fixups ---

    # Fix "The scc_sp protocol (Semaphore Communications Sec"
    if desc.endswith("Semaphore Communications Sec"):
        desc = desc+". Pro.)"

    # Fix "Taiwanese Web portal (news, webmail, shopping"
    if desc.endswith("(news, webmail, shopping"):
        desc = desc+", etc)"

    # Fix "Chinese mobile (Android applications."
    if desc.endswith("(Android applications"):
        desc = desc+")"

    # Trim "OpenGW (aka VPN Gate) is a Public VPN Relay Servers service, used in several VPN solutions (example: PacketiX"
    if desc.endswith(" (example: PacketiX"):
        desc = desc[:-19]

    # Strip end of string
    if desc.endswith(' (e.g'):
        desc = desc[:-5]

    # Add WS to fix bad quoting.
    if name == "clearcase":
        desc = desc.replace('Rational"division', 'Rational" division')

    if name == "mqtt":
        desc = desc.replace('Things"connectivity', 'Things" connectivity')

    if name == "rovi":
        desc = desc.replace('recommendation"on devices', 'recommendation" on devices')

    # Substitution table
    desc = desc.replace('Afgan', 'Afghan')
    desc = desc.replace('asian', 'Asian')
    desc = desc.replace('Azerbadjani', 'Azerbaijani')
    desc = desc.replace('Azebaijani', 'Azerbaijani')
    desc = desc.replace(' russian', ' Russian')
    desc = desc.replace('BelaRussian', 'Belarssian')
    desc = desc.replace('belaRusian', 'Belarusian')
    desc = desc.replace('belarusian', 'Belarusian')
    desc = desc.replace('Bittorrent', 'BitTorrent')
    desc = desc.replace('Brazalian', 'Brazilian')
    desc = desc.replace('CHinese', 'Chinese')
    desc = desc.replace('Caisse d Allocation familiale', 'Caisse d\'allocation familiale')
    desc = desc.replace('Chilian', 'Chilean')
    desc = desc.replace('Coasta rica', 'Costa Rica')
    desc = desc.replace('Columbian', 'Colombian')
    desc = desc.replace('Cote d Ivoire', 'Cote d\'Ivoire')
    desc = desc.replace('Crotaian', 'Croatian')
    desc = desc.replace('Cypriote', 'Cypriot')
    desc = desc.replace('Deutch', 'German')
    desc = desc.replace('Fondation', 'Foundation')
    desc = desc.replace('Israelian', 'Israeli')
    desc = desc.replace('Japanase', 'Japanese')
    desc = desc.replace('Lebaneese', 'Lebanese')
    desc = desc.replace('Lituania', 'Lithuania')
    desc = desc.replace('Luxemburg', 'Luxembourg')
    desc = desc.replace('Norvegian', 'Norwegian')
    desc = desc.replace('Portugese', 'Portuguese')
    desc = desc.replace('Polinesian', 'Polynesian')
    desc = desc.replace('Quatar', 'Qatar')
    desc = desc.replace('RAppler', 'Rappler')
    desc = desc.replace('Sri lanka', 'SriLanka')
    desc = desc.replace('Sri Lanka', 'SriLanka')
    desc = desc.replace('Srilanka', 'SriLanka')
    desc = desc.replace('VOIP', 'VoIP')
    desc = desc.replace('Venezuelian', 'Venezuelan')
    desc = desc.replace('Web site', 'Website')
    desc = desc.replace('Worlwide', 'Worldwide')
    desc = desc.replace('american', 'American')
    desc = desc.replace('an NIS', 'a NIS')
    desc = desc.replace(' apple', ' Apple')
    desc = desc.replace('subcription', 'subscription')
    desc = desc.replace('artifacts', 'artefacts')
    desc = desc.replace('bloomberg', 'Bloomberg')
    desc = desc.replace('bybass', 'bypass')
    desc = desc.replace('chinese', 'Chinese')
    desc = desc.replace('controlling', 'controling')
    desc = desc.replace('crackle', 'Crackle')
    desc = desc.replace('cypriot', 'Cypriot')
    desc = desc.replace('czech', 'Czech')
    desc = desc.replace('developement', 'development')
    desc = desc.replace('developped', 'developed')
    desc = desc.replace('entertaiment', 'entertainment')
    desc = desc.replace('entertainement', 'entertainment')
    desc = desc.replace('entreprises', 'enterprises')
    desc = desc.replace('environnement', 'environment')
    desc = desc.replace('french', 'French')
    desc = desc.replace('german', 'German')
    desc = desc.replace('hong kong', 'Hong Kong')
    desc = desc.replace(' html', ' HTML')
    desc = desc.replace(' http ', ' HTTP ')
    desc = desc.replace('hungarian', 'Hungarian')
    desc = desc.replace('informations', 'information')
    desc = desc.replace('investigate news', 'investigative news')
    desc = desc.replace('iranian', 'Iranian')
    desc = desc.replace('japanese', 'Japanese')
    desc = desc.replace('knowlegde', 'knowledge')
    desc = desc.replace('negociating', 'negotiating')
    desc = desc.replace('portral', 'portal')
    desc = desc.replace('protal', 'portal')
    desc = desc.replace('provifing', 'providing')
    desc = desc.replace('puglin', 'plugin')
    desc = desc.replace('ressources', 'resources')
    desc = desc.replace('singaporean', 'Singaporean')
    desc = desc.replace('softwares', 'software')
    desc = desc.replace('swedish', 'Swedish')
    desc = desc.replace('targetting', 'targeting')
    desc = desc.replace('the training, the marketing, the conferences and the online', 'training, marketing, conferences and online')
    desc = desc.replace('thoughput', 'throughput')
    desc = desc.replace('tranfers', 'transfers')
    desc = desc.replace('transfering', 'transferring')
    desc = desc.replace('travelling', 'traveling')
    desc = desc.replace('tunnelled', 'tunneled')
    desc = desc.replace('tunnelling', 'tunneling')
    desc = desc.replace('vietnamese', 'Vietnamese')
    desc = desc.replace('voip', 'VoIP')
    desc = desc.replace('Voip', 'VoIP')
    desc = desc.replace('web site', 'website')
    desc = desc.replace('web-messagery', 'web-messaging')
    desc = desc.replace('zealander', 'Zealander')
    desc = desc.replace('etc..', 'etc')
    desc = desc.replace('....', ' etc')
    desc = desc.replace(' ...', ' etc')
    desc = desc.replace('...', ' etc')
    desc = desc.replace('etc etc', 'etc')
    desc = desc.replace(' Tv ', ' TV ')
    desc = desc.replace(' Website', ' website')
    desc = desc.replace(' ah protocol ', ' AH protocol ')
    desc = desc.replace(' an European', ' a European')
    desc = desc.replace(' an IBM\'s mainframe network standards', ' IBM\'s mainframe network standard')
    desc = desc.replace(' arab ', ' Arab ')
    desc = desc.replace(' dns ', ' DNS ')
    desc = desc.replace(' esp ', ' ESP ')
    desc = desc.replace(' something called usbmux, this is a system for multiplexing several connections', ' usbmux')
    desc = desc.replace(' ssl ', ' SSL ')
    desc = desc.replace(' tv ', ' TV ')
    desc = desc.replace(' tv-', ' TV-')
    desc = desc.replace('(versions prior to 10.0.0.270) ', '')
    desc = desc.replace('', '')
    desc = desc.replace('(DDX)', '(DDX))')
    desc = desc.replace('wowen', 'women')
    desc = desc.replace('women lifestyle', 'women\'s lifestyle')
    desc = desc.replace('classifieds ads', 'classified ads')
    desc = desc.replace('classifed', 'classified')
    desc = desc.replace('electonics', 'electronics')
    desc = desc.replace('egyptian', 'Egyptian')
    desc = desc.replace('Hungarish', 'Hungarian')
    desc = desc.replace('a instant', 'an instant')
    desc = desc.replace('wep portal', 'web portal')
    desc = desc.replace('indonesian', 'Indonesian')
    desc = desc.replace('localted', 'located')
    desc = desc.replace('asian', 'Asian')
    desc = desc.replace('messenging', 'messaging')
    desc = desc.replace('indonesian', 'Indonesian')
    desc = desc.replace('salvadorian', 'Salvadorian')
    desc = desc.replace('onlive', 'online')
    desc = desc.replace('entertainmment', 'entertainment')
    desc = desc.replace('ONline', 'Online')
    desc = desc.replace('webiste', 'website')
    desc = desc.replace('remplaced', 'replaced')
    desc = desc.replace(' a advertising', ' an advertising')
    desc = desc.replace(' vide ', ' video ')
    desc = desc.replace('taiwanese', 'Taiwanese')
    desc = desc.replace('is not used anymore', 'no longer used')
    desc = desc.replace('palestinian', 'Palestinian')
    desc = desc.replace(' hosts teachertube.com', ' host teachertube.com')
    desc = desc.replace(' in around', ' around')
    desc = desc.replace('inspired of ', 'inspired by ')
    desc = desc.replace('allows to share and discover', 'allows sharing and discovering')
    desc = desc.replace('allows to use ', 'allows using ')
    desc = desc.replace('allows user to ', 'allows users to ')
    desc = desc.replace(' an banking', ' and banking')
    desc = desc.replace('"connectivity', '" connectivity')
    desc = desc.replace('Skype etc', 'Skype, etc')
    desc = desc.replace(' a NGO ', ' an NGO ')
    desc = desc.replace(' ( http://www.51.com )', '')
    desc = desc.replace(' ( bbs.51.com )', '')
    desc = desc.replace(' ( http://music.51.com )', '')
    desc = desc.replace(' ( http://home.51.com/posting )', '')
    desc = desc.replace(' ( https://jiveon.com )', '')
    desc = desc.replace(' ( http://mail.daum.net )', '')
    desc = desc.replace(' ( https://www-am2.egnyte.com/corp/registration/lp-join-the-thousands.html )', '')
    desc = desc.replace(' ( http://try.bbcollaborate.com/trial/register.go )', '')
    desc = desc.replace(' ( http://fotoweb.fotoware.com )', '')
    desc = desc.replace(' ( http://games.mail.ru )', '')
    desc = desc.replace(' ( http://mekusharim.walla.co.il/ )', '')
    desc = desc.replace(' ( http://www.mydownloader.net/ )', '')
    desc = desc.replace(' ( http://mail.naver.com/ )', '')
    desc = desc.replace(' ( http://www.nefsis.com/ )', '')
    desc = desc.replace(' ( http://my.mail.ru )', '')
    desc = desc.replace(' ( internet.mail.ru )', '')
    desc = desc.replace(' (www.site.com)', '')
    desc = desc.replace('network equipments', 'network equipment')
    desc = desc.replace('(popular', '(a popular')
    desc = desc.replace('bandwith', 'bandwidth')
    desc = desc.replace('host .', 'host ')
    desc = desc.replace('humoristic', 'humorous')
    desc = desc.replace('Entertainment(SOE)', 'Entertainment (SOE)')
    desc = desc.replace(', specific to ixEngine,', '')
    desc = desc.replace(' Inc ', ' Inc. ')
    desc = desc.replace('(Deprecated) (Deprecated) ', '(Deprecated) ')
    desc = desc.replace('(Deprecated) Deprecated', '(Deprecated) This is deprecated')
    desc = desc.replace('(Deprecated) website', '(Deprecated) Website')
    desc = desc.replace(' and which', ' which')
    desc = desc.replace('protocol plug-in ', '')
    desc = desc.replace('', '')

    # ---

    # json.dumps quotes the string and escapes quotes
    desc = json.dumps(desc)

    # Parenthesis check.
    if desc.count('[') != desc.count(']'):
        print("WARNING: [ ] mismatch in "+desc)
    if desc.count('{') != desc.count('}'):
        print("WARNING: { } mismatch in "+desc)
    if desc.count('(') != desc.count(')'):
        print("WARNING: ( ) mismatch in "+desc)

    return desc
    #apps[name] = desc


def show_apps(apps, deprecated, out):
    first = True
    for key in sorted(apps.iterkeys()):
        if not first:
           out.write("\n")
        first = False
        out.write("\t\t\tenum \""+key+"\" {\n")
        out.write("\t\t\t\topd:help "+apps[key]+";\n")
        if (deprecated[key]):
            out.write ("\t\t\t\tstatus obsolete;\n")
        out.write("\t\t\t}\n")

def usage(inp, outp):
    print("Convert Qosmos JSON to vyatta YANG")
    print
    print("-j, --json FILENAME    Specify input json file (default: "+inp+")")
    print("-y, --yang FILENAME    Specify output yang file (default: "+outp+")")


#
# Main
#
def main():
    INPUT_JSON="protocol_records.js"
    OUTPUT_YANG="output.yang"

    apps = {}
    deprecated = {}

    #
    # Parse args.
    #
    try:
        opts, args = getopt.getopt(sys.argv[1:], "hj:y:", ["help", "json=", "yang="])
    except getopt.GetoptError as err:
        print(str(err))
        sys.exit(2)

    for opt, arg in opts:
        if opt in ("-j", "--json"):
            INPUT_JSON = arg
        if opt in ("-y", "--yang"):
            OUTPUT_YANG = arg
        if opt in ("-h", "--help"):
            usage(INPUT_JSON, OUTPUT_YANG)
            return 0

    #
    # Load the JSON.
    #
    try:
        with open(INPUT_JSON) as data_file:
            header = data_file.readline()
            data = json.load(data_file)
    except IOError:
        print "Can't read from "+INPUT_JSON
        return 2

    #
    # Open the output YANG file
    #
    try:
        out = open(OUTPUT_YANG, "w")
    except IOError:
        print "Can't write to "+OUTPUT_YANG
        return 2

    #
    # Output header.
    #
    out.write("\ttypedef application-names {\n")
    out.write("\t\ttype enumeration {\n")

    #
    # Process existing non-blacklisted apps.
    #
    for app in data:
        name = app["name"].encode('ascii', 'ignore').decode('ascii')

        if name in existinglist and name not in blacklist:
            try:
                rt = app["refer_to"]
                print("ignoring '%s' alias for '%s'" % (name, app["refer_to"]))
                continue
            except (KeyError, AttributeError):
                apps[name] = getdesc(app, name, deprecated)

    show_apps(apps, deprecated, out)
    out.write("\n")

    #
    # Process new non-blacklisted apps.
    #
    apps.clear()
    for app in data:
        name = app["name"].encode('ascii', 'ignore').decode('ascii')

        if name not in existinglist and name not in blacklist:
            try:
                rt = app["refer_to"]
                print("ignoring '%s' alias for '%s'" % (name, app["refer_to"]))
                continue
            except (KeyError, AttributeError):
                apps[name] = getdesc(app, name, deprecated)

    show_apps(apps, deprecated, out)

    #
    # Interstitial.
    #
    out.write("\t\t}\n")
    out.write("\t}\n")
    out.write("\n")
    out.write("\ttypedef relaxed-application-names {\n")
    out.write("\t\ttype enumeration {\n")

    #
    # Process blacklisted apps.
    #
    apps.clear()
    for app in data:
        name = app["name"].encode('ascii', 'ignore').decode('ascii')

        if name in blacklist:
            apps[name] = getdesc(app, name, deprecated)

    show_apps(apps, deprecated, out)

    #
    # Footer.
    #
    out.write("\t\t}\n")
    out.write("\t}\n")
    out.write("}\n")

    #
    # All done.
    #
    out.close()


#
#
#
sys.exit(main())
